import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { LocationClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../LocationClient";
import { DescribeMapRequest, DescribeMapResponse } from "../models/models_0";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link DescribeMapCommand}.
 */
export interface DescribeMapCommandInput extends DescribeMapRequest {
}
/**
 * @public
 *
 * The output of {@link DescribeMapCommand}.
 */
export interface DescribeMapCommandOutput extends DescribeMapResponse, __MetadataBearer {
}
declare const DescribeMapCommand_base: {
    new (input: DescribeMapCommandInput): import("@smithy/smithy-client").CommandImpl<DescribeMapCommandInput, DescribeMapCommandOutput, LocationClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (input: DescribeMapCommandInput): import("@smithy/smithy-client").CommandImpl<DescribeMapCommandInput, DescribeMapCommandOutput, LocationClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Retrieves the map resource details.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { LocationClient, DescribeMapCommand } from "@aws-sdk/client-location"; // ES Modules import
 * // const { LocationClient, DescribeMapCommand } = require("@aws-sdk/client-location"); // CommonJS import
 * const client = new LocationClient(config);
 * const input = { // DescribeMapRequest
 *   MapName: "STRING_VALUE", // required
 * };
 * const command = new DescribeMapCommand(input);
 * const response = await client.send(command);
 * // { // DescribeMapResponse
 * //   MapName: "STRING_VALUE", // required
 * //   MapArn: "STRING_VALUE", // required
 * //   PricingPlan: "STRING_VALUE",
 * //   DataSource: "STRING_VALUE", // required
 * //   Configuration: { // MapConfiguration
 * //     Style: "STRING_VALUE", // required
 * //     PoliticalView: "STRING_VALUE",
 * //     CustomLayers: [ // CustomLayerList
 * //       "STRING_VALUE",
 * //     ],
 * //   },
 * //   Description: "STRING_VALUE", // required
 * //   Tags: { // TagMap
 * //     "<keys>": "STRING_VALUE",
 * //   },
 * //   CreateTime: new Date("TIMESTAMP"), // required
 * //   UpdateTime: new Date("TIMESTAMP"), // required
 * // };
 *
 * ```
 *
 * @param DescribeMapCommandInput - {@link DescribeMapCommandInput}
 * @returns {@link DescribeMapCommandOutput}
 * @see {@link DescribeMapCommandInput} for command's `input` shape.
 * @see {@link DescribeMapCommandOutput} for command's `response` shape.
 * @see {@link LocationClientResolvedConfig | config} for LocationClient's `config` shape.
 *
 * @throws {@link AccessDeniedException} (client fault)
 *  <p>The request was denied because of insufficient access or permissions. Check with an
 *       administrator to verify your permissions.</p>
 *
 * @throws {@link InternalServerException} (server fault)
 *  <p>The request has failed to process because of an unknown server error, exception, or failure.</p>
 *
 * @throws {@link ResourceNotFoundException} (client fault)
 *  <p>The resource that you've entered was not found in your AWS account.</p>
 *
 * @throws {@link ThrottlingException} (client fault)
 *  <p>The request was denied because of request throttling.</p>
 *
 * @throws {@link ValidationException} (client fault)
 *  <p>The input failed to meet the constraints specified by the AWS service. </p>
 *
 * @throws {@link LocationServiceException}
 * <p>Base exception class for all service exceptions from Location service.</p>
 *
 *
 * @public
 */
export declare class DescribeMapCommand extends DescribeMapCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: DescribeMapRequest;
            output: DescribeMapResponse;
        };
        sdk: {
            input: DescribeMapCommandInput;
            output: DescribeMapCommandOutput;
        };
    };
}
